Module: MnoEnterprise::Concerns::Controllers::AngularCSRF
- Extended by:
- ActiveSupport::Concern
- Included in:
- ApplicationController
- Defined in:
- lib/mno_enterprise/concerns/controllers/angular_csrf.rb
Overview
This module allow Angular to works well with Rails CSRF protection It's intended for AngularJS app served outside of the Rails asset pipeline. See
Defined Under Namespace
Modules: ClassMethods